phpgroupware-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Phpgroupware-cvs] property/setup tables_current.inc.php setup.inc...


From: Sigurd Nes
Subject: [Phpgroupware-cvs] property/setup tables_current.inc.php setup.inc...
Date: Thu, 20 Apr 2006 09:08:51 +0000

CVSROOT:        /sources/phpgroupware
Module name:    property
Branch:         
Changes by:     Sigurd Nes <address@hidden>     06/04/20 09:08:51

Modified files:
        setup          : tables_current.inc.php setup.inc.php 
                         tables_update.inc.php 

Log message:
        

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/phpgroupware/property/setup/tables_current.inc.php.diff?tr1=1.58&tr2=1.59&r1=text&r2=text
http://cvs.savannah.gnu.org/viewcvs/phpgroupware/property/setup/setup.inc.php.diff?tr1=1.40&tr2=1.41&r1=text&r2=text
http://cvs.savannah.gnu.org/viewcvs/phpgroupware/property/setup/tables_update.inc.php.diff?tr1=1.43&tr2=1.44&r1=text&r2=text

Patches:
Index: property/setup/setup.inc.php
diff -u property/setup/setup.inc.php:1.40 property/setup/setup.inc.php:1.41
--- property/setup/setup.inc.php:1.40   Wed Apr 19 08:35:18 2006
+++ property/setup/setup.inc.php        Thu Apr 20 09:08:51 2006
@@ -8,12 +8,12 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: setup.inc.php,v 1.40 2006/04/19 08:35:18 sigurdne Exp $
+       * @version $Id: setup.inc.php,v 1.41 2006/04/20 09:08:51 sigurdne Exp $
        */
 
        $setup_info['property']['name']      = 'property';
        $setup_info['property']['title']         = 'Property';
-       $setup_info['property']['version']   = '0.9.17.520';
+       $setup_info['property']['version']   = '0.9.17.521';
        $setup_info['property']['app_order'] = 8;
        $setup_info['property']['enable']    = 1;
        $setup_info['property']['app_group']    = 'office';
Index: property/setup/tables_current.inc.php
diff -u property/setup/tables_current.inc.php:1.58 
property/setup/tables_current.inc.php:1.59
--- property/setup/tables_current.inc.php:1.58  Wed Apr 19 08:35:18 2006
+++ property/setup/tables_current.inc.php       Thu Apr 20 09:08:51 2006
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: tables_current.inc.php,v 1.58 2006/04/19 08:35:18 
sigurdne Exp $
+       * @version $Id: tables_current.inc.php,v 1.59 2006/04/20 09:08:51 
sigurdne Exp $
        */
 
        $phpgw_baseline = array(
@@ -2179,7 +2179,8 @@
                                'user_id' => array('type' => 'int', 'precision' 
=> 4,'nullable' => True),
                                'entry_date' => array('type' => 'int', 
'precision' => 4,'nullable' => True),
                                'budget_cost' => array('type' => 'int', 
'precision' => 4,'default' => '0','nullable' => True),
-                               'remark' => array('type' => 'text','nullable' 
=> True)
+                               'remark' => array('type' => 'text','nullable' 
=> True),
+                               'distribute_year' => array('type' => 
'text','nullable' => True)
                        ),
                        'pk' => array('id'),
                        'fk' => array(),
Index: property/setup/tables_update.inc.php
diff -u property/setup/tables_update.inc.php:1.43 
property/setup/tables_update.inc.php:1.44
--- property/setup/tables_update.inc.php:1.43   Wed Apr 19 08:35:17 2006
+++ property/setup/tables_update.inc.php        Thu Apr 20 09:08:51 2006
@@ -8,7 +8,7 @@
        * @internal Development of this application was funded by 
http://www.bergen.kommune.no/bbb_/ekstern/
        * @package property
        * @subpackage setup
-       * @version $Id: tables_update.inc.php,v 1.43 2006/04/19 08:35:17 
sigurdne Exp $
+       * @version $Id: tables_update.inc.php,v 1.44 2006/04/20 09:08:51 
sigurdne Exp $
        */
 
        /**
@@ -1260,7 +1260,7 @@
 
 
        /**
        * Update property version from 0.9.17.518 to 0.9.17.519
        */
 
        $test[] = '0.9.17.519';
@@ -1275,3 +1275,20 @@
                $GLOBALS['setup_info']['property']['currentver'] = '0.9.17.520';
                return $GLOBALS['setup_info']['property']['currentver'];
        }
+
+
+       /**
+       * Update property version from 0.9.17.520 to 0.9.17.521
+       */
+
+       $test[] = '0.9.17.520';
+       function property_upgrade0_9_17_520()
+       {
+               $GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+               
$GLOBALS['phpgw_setup']->oProc->AddColumn('fm_budget_basis','distribute_year',array('type'
 => 'text','nullable' => True));
+               
+               $GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
+               $GLOBALS['setup_info']['property']['currentver'] = '0.9.17.521';
+               return $GLOBALS['setup_info']['property']['currentver'];
+       }
@@ -1260,7 +1260,7 @@
 
        /**
-       * Update property version from 0.9.17.518 to 0.9.17.519
+       * Update property version from 0.9.17.519 to 0.9.17.520
        */
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]